aboutsummaryrefslogtreecommitdiff
path: root/discord/ext
diff options
context:
space:
mode:
Diffstat (limited to 'discord/ext')
-rw-r--r--discord/ext/commands/converter.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/discord/ext/commands/converter.py b/discord/ext/commands/converter.py
index 9fc6cf6d..81d3a00e 100644
--- a/discord/ext/commands/converter.py
+++ b/discord/ext/commands/converter.py
@@ -336,11 +336,11 @@ class GameConverter(Converter):
class InviteConverter(Converter):
"""Converts to a :class:`Invite`.
This is done via an HTTP request using :meth:`.Bot.get_invite`.
"""
async def convert(self, ctx, argument):
try:
- invite = await ctx.bot.get_invite(argument)
+ invite = await ctx.bot.fetch_invite(argument)
return invite
except Exception as exc:
raise BadArgument('Invite is invalid or expired') from exc
@@ -336,11 +336,11 @@ class GameConverter(Converter):
class InviteConverter(Converter):
"""Converts to a :class:`Invite`.
- This is done via an HTTP request using :meth:`.Bot.get_invite`.
+ This is done via an HTTP request using :meth:`.Bot.fetch_invite`.
"""
async def convert(self, ctx, argument):